Package: adimpro
Version: 0.9.6
Date: 2023-09-05
Title: Adaptive Smoothing of Digital Images
Author: Karsten Tabelow <tabelow@wias-berlin.de>,
             		Joerg Polzehl <polzehl@wias-berlin.de>
Maintainer: Karsten Tabelow <tabelow@wias-berlin.de>
Depends: R (>= 3.2.0)
Imports: awsMethods (>= 1.1-1), grDevices, methods
SystemRequirements: Image Magick (for reading non PPM format), dcraw
        (for reading RAW images).
Description: Implements tools for manipulation of digital
             		images and the Propagation Separation approach
             		by Polzehl and Spokoiny (2006) <DOI:10.1007/s00440-005-0464-1>
                        for smoothing digital images, see Polzehl and Tabelow (2007)
                        <DOI:10.18637/jss.v019.i01>.
License: GPL (>= 2)
Copyright: This package is Copyright (C) 2006-2023 Weierstrass
        Institute for Applied Analysis and Stochastics.
URL: https://www.wias-berlin.de/software/imaging/
NeedsCompilation: yes
Packaged: 2023-09-05 21:11:20 UTC; polzehl
Repository: CRAN
Date/Publication: 2023-09-06 12:40:02 UTC
Built: R 4.2.0; aarch64-apple-darwin20; 2023-09-13 02:22:05 UTC; unix
Archs: adimpro.so.dSYM
